@@ -35,9 +35,15 @@ FAILEDOPERATION_DEVICERESULTTIMEOUT = 'FailedOperation.DeviceResultTimeOut'
 # 域名CNAME解析未成功，请到域名服务商处检查配置
 FAILEDOPERATION_NOMATCHEDCNAME = 'FailedOperation.NoMatchedCname'
 
+# 没有该子用户
+FAILEDOPERATION_NOTHAVESUBUSER = 'FailedOperation.NotHaveSubUser'
+
 # 请求超时
 FAILEDOPERATION_REQUESTTIMEOUT = 'FailedOperation.RequestTimeout'
 
+# 服务器内部错误
+INTERNALERROR_SERVERINTERNALERROR = 'InternalError.ServerInternalError'
+
 # 无效的输入参数
 INVALIDPARAMETER = 'InvalidParameter'
 
@@ -62,6 +68,9 @@ INVALIDPARAMETER_INVALIDLIFERULEPARAM = 'InvalidParameter.InvalidLifeRuleParam'
 # 无效的组织参数
 INVALIDPARAMETER_INVALIDORGANIZATIONPARAM = 'InvalidParameter.InvalidOrganizationParam'
 
+# 无效的输入参数
+INVALIDPARAMETER_INVALIDPARAMETER = 'InvalidParameter.InvalidParameter'
+
 # 参数格式不对或缺少参数
 INVALIDPARAMETER_INVALIDPARAMETERFORMAT = 'InvalidParameter.InvalidParameterFormat'
 
@@ -98,6 +107,9 @@ INVALIDPARAMETERVALUE_CHANNELLISTMUSTBENOTEMPTY = 'InvalidParameterValue.Channel
 # ChannelList的数量必须小于1000
 INVALIDPARAMETERVALUE_CHANNELNUMBERMUSTBELESSTHANONETHOUSAND = 'InvalidParameterValue.ChannelNumberMustBeLessThanOneThousand'
 
+# 通道数量超过限制范围
+INVALIDPARAMETERVALUE_CHANNELSEXCEEDSRANGE = 'InvalidParameterValue.ChannelsExceedsRange'
+
 # 包含无效的ChannelId
 INVALIDPARAMETERVALUE_CONTAININVALIDCHANNELID = 'InvalidParameterValue.ContainInvalidChannelId'
 
@@ -203,6 +215,12 @@ INVALIDPARAMETERVALUE_INVALIDDEVICETYPE = 'InvalidParameterValue.InvalidDeviceTy
 # 无效的域名，长度或内容不符合规则
 INVALIDPARAMETERVALUE_INVALIDDOMAIN = 'InvalidParameterValue.InvalidDomain'
 
+# 无效的域名类型参数
+INVALIDPARAMETERVALUE_INVALIDDOMAINTYPE = 'InvalidParameterValue.InvalidDomainType'
+
+# 无效的使能参数
+INVALIDPARAMETERVALUE_INVALIDENALBEVALUE = 'InvalidParameterValue.InvalidEnalbeValue'
+
 # 无效的结束时间
 INVALIDPARAMETERVALUE_INVALIDENDTIME = 'InvalidParameterValue.InvalidEndTime'
 
@@ -224,6 +242,9 @@ INVALIDPARAMETERVALUE_INVALIDGATEWAYPROTOCOLTYPE = 'InvalidParameterValue.Invali
 # 无效的Ipv4地址
 INVALIDPARAMETERVALUE_INVALIDIPV4 = 'InvalidParameterValue.InvalidIpv4'
 
+# 无效的关键字
+INVALIDPARAMETERVALUE_INVALIDKEYWORD = 'InvalidParameterValue.InvalidKeyword'
+
 # 名称为空或填写有误
 INVALIDPARAMETERVALUE_INVALIDNAME = 'InvalidParameterValue.InvalidName'
 
@@ -254,6 +275,12 @@ INVALIDPARAMETERVALUE_INVALIDPULLSTATE = 'InvalidParameterValue.InvalidPullState
 # 无效的推流鉴权开关值
 INVALIDPARAMETERVALUE_INVALIDPUSHSTATE = 'InvalidParameterValue.InvalidPushState'
 
+# 无效的RTMP推流AppName
+INVALIDPARAMETERVALUE_INVALIDRTMPAPPNAME = 'InvalidParameterValue.InvalidRTMPAppName'
+
+# 无效的RTMP推流StreamName
+INVALIDPARAMETERVALUE_INVALIDRTMPSTREAMNAME = 'InvalidParameterValue.InvalidRTMPStreamName'
+
 # 无效的取回模式
 INVALIDPARAMETERVALUE_INVALIDRETRIEVALMODE = 'InvalidParameterValue.InvalidRetrievalMode'
 
@@ -290,6 +317,9 @@ INVALIDPARAMETERVALUE_INVALIDTIMESECTIONVALUE = 'InvalidParameterValue.InvalidTi
 # 热存储至少1天, 最多3650天
 INVALIDPARAMETERVALUE_INVALIDTRANSITIONRANGE = 'InvalidParameterValue.InvalidTransitionRange'
 
+# 无效的用户参数
+INVALIDPARAMETERVALUE_INVALIDUSERPARAM = 'InvalidParameterValue.InvalidUserParam'
+
 # 无效的用户名，长度或内容不符合规则
 INVALIDPARAMETERVALUE_INVALIDUSERNAME = 'InvalidParameterValue.InvalidUsername'
 
@@ -320,6 +350,12 @@ INVALIDPARAMETERVALUE_OUTOFTIMERANGE = 'InvalidParameterValue.OutOfTimeRange'
 # 通道数量一次最多添加5000路
 INVALIDPARAMETERVALUE_PLANCHANNELSEXCEEDSRANGE = 'InvalidParameterValue.PlanChannelsExceedsRange'
 
+# 计划名称不能重复
+INVALIDPARAMETERVALUE_PLANNAMEREPEAT = 'InvalidParameterValue.PlanNameRepeat'
+
+# RTMP推流自定义AppName及StreamName不能重复配置
+INVALIDPARAMETERVALUE_RTMPPUSHSTREAMPARAMREPEAT = 'InvalidParameterValue.RTMPPushStreamParamRepeat'
+
 # 一个取回任务最多添加32个设备通道
 INVALIDPARAMETERVALUE_RETRIEVETASKCHANNELSEXCEEDSRANGE = 'InvalidParameterValue.RetrieveTaskChannelsExceedsRange'
 
@@ -386,12 +422,18 @@ MISSINGPARAMETER_EMPTYTIMESECTION = 'MissingParameter.EmptyTimeSection'
 # 缺少生命周期参数
 MISSINGPARAMETER_MISSINGLIFERULEPARAM = 'MissingParameter.MissingLifeRuleParam'
 
+# 缺少必须参数
+MISSINGPARAMETER_MISSINGMUSTPARAMETER = 'MissingParameter.MissingMustParameter'
+
 # 缺少取回任务参数
 MISSINGPARAMETER_MISSINGRETRIEVETASKPARAM = 'MissingParameter.MissingRetrieveTaskParam'
 
 # 没有更新信息
 MISSINGPARAMETER_MISSINGUPDATEDINFO = 'MissingParameter.MissingUpdatedInfo'
 
+# 缺少用户信息
+MISSINGPARAMETER_MISSINGUSERINFO = 'MissingParameter.MissingUserInfo'
+
 # 带宽受限
 OPERATIONDENIED_BANDWIDTHLIMITZERO = 'OperationDenied.BandwidthLimitZero'
 
@@ -404,6 +446,12 @@ OPERATIONDENIED_CONNECTSLIMITZERO = 'OperationDenied.ConnectsLimitZero'
 # 新增组织树失败，超出组织树的最大深度
 OPERATIONDENIED_EXCEEDEDMAXIMUMDEPTH = 'OperationDenied.ExceededMaximumDepth'
 
+# 该功能需要申请白名单配置
+OPERATIONDENIED_NOWHITELIST = 'OperationDenied.NoWhitelist'
+
+# 播放鉴权未开启
+OPERATIONDENIED_PLAYAUTHNOTENABLED = 'OperationDenied.PlayAuthNotEnabled'
+
 # 资源不可达，该资源不属于该地域
 REGIONERROR_RESOURCEUNREACHABLE = 'RegionError.ResourceUnreachable'
 
@@ -485,8 +533,14 @@ UNSUPPORTEDOPERATION_ORGLINKDEV = 'UnsupportedOperation.OrgLinkDev'
 # 组织下有挂靠的组织，不允许删除
 UNSUPPORTEDOPERATION_ORGLINKORG = 'UnsupportedOperation.OrgLinkOrg'
 
+# RTMP推流域名不存在
+UNSUPPORTEDOPERATION_PUSHDOMAINNOTEXIST = 'UnsupportedOperation.PushDomainNotExist'
+
 # Scale和Pos参数不支持同时下发
 UNSUPPORTEDOPERATION_SCALEANDPOSBOTHEXIST = 'UnsupportedOperation.ScaleAndPosBothExist'
 
 # StreamType和Resolution参数不支持同时下发
 UNSUPPORTEDOPERATION_STREAMTYPEORRESOLUTION = 'UnsupportedOperation.StreamTypeOrResolution'
+
+# 该地域未开通内网服务
+UNSUPPORTEDOPERATION_UNOPENEDINTRANETSERVICESINREGION = 'UnsupportedOperation.UnopenedIntranetServicesInRegion'
